<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Kõik kalendrid pole täielikult puhverdatud",
"Everything seems to be completely cached" => "Kõik näib olevat puhverdatud",
"No calendars found." => "Kalendreid ei leitud.",
"No events found." => "Üritusi ei leitud.",
"Wrong calendar" => "Vale kalender",
"You do not have the permissions to edit this event." => "Sul pole õigusi selle ürituse muutmiseks.",
"The file contained either no events or all events are already saved in your calendar." => "Failis polnud ühtegi üritust või kõik üritused on juba sinu kalendrisse salvestatud.",
"Import failed" => "Importimine ebaõnnestus",
"New Timezone:" => "Uus ajavöönd:",
"Timezone changed" => "Ajavöönd on muudetud",
"Invalid request" => "Vigane päring",
"Calendar" => "Kalender",
"Deletion failed" => "Kustutamine ebaõnnestus",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "grupp",
"can edit" => "saab muuta",
"can share" => "saab jagada",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Pühapäev",
"Monday" => "Esmaspäev",
"Tuesday" => "Teisipäev",
"Wednesday" => "Kolmapäev",
"Thursday" => "Neljapäev",
"Friday" => "Reede",
"Saturday" => "Laupäev",
"Sun." => "P",
"Mon." => "E",
"Tue." => "T",
"Wed." => "K",
"Thu." => "N",
"Fri." => "R",
"Sat." => "L",
"January" => "Jaanuar",
"February" => "Veebruar",
"March" => "Märts",
"April" => "Aprill",
"May" => "Mai",
"June" => "Juuni",
"July" => "Juuli",
"August" => "August",
"September" => "September",
"October" => "Oktoober",
"November" => "November",
"December" => "Detsember",
"Jan." => "Jaan.",
"Feb." => "Veebr.",
"Mar." => "Mär.",
"Apr." => "Apr.",
"May." => "Mai",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Sep." => "Sept.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dets.",
"All day" => "Kogu päev",
"New Calendar" => "Uus kalender",
"Missing or invalid fields" => "Puuduvad või vigased väljad",
"Title" => "Pealkiri",
"From Date" => "Alates kuupäevast",
"From Time" => "Alates kellaajast",
"To Date" => "Kuni kuupäevani",
"To Time" => "Kuni kellaajani",
"The event ends before it starts" => "Üritus lõpeb enne, kui see algab",
"There was a database fail" => "Tekkis andmebaasi viga",
"Interval is not valid. It must be a positive integer!" => "Intervall pole korrektne. See peab olema positiivne arv!",
"Birthday" => "Sünnipäev",
"Business" => "Äri",
"Call" => "Helista",
"Clients" => "Kliendid",
"Deliverer" => "Kohaletoimetaja",
"Holidays" => "Pühad",
"Ideas" => "Ideed",
"Journey" => "Reis",
"Jubilee" => "Juubel",
"Meeting" => "Kohtumine",
"Other" => "Muu",
"Personal" => "Isiklik",
"Projects" => "Projektid",
"Questions" => "Küsimused",
"Work" => "Töö",
"by" => "lisas",
"unnamed" => "nimetu",
"You do not have the permissions to update this calendar." => "Sul pole õigusi selle kalendri uuendamiseks.",
"You do not have the permissions to delete this calendar." => "Sul pole õigusi selle kalendri kustutamiseks.",
"You do not have the permissions to add to this calendar." => "Sul pole õigusi selle kalendri lisamiseks.",
"You do not have the permissions to add events to this calendar." => "Sul pole õigusi sellesse kalendrisse ürituste lisamiseks.",
"You cannot add non-public events to a shared calendar." => "Sa ei saa lisada jagatud kalendrisse mitte-avalikke sündmusi.",
"You do not have the permissions to delete this event." => "Sul pole õigusi selle ürituse kustutamiseks.",
"Busy" => "Hõivatud",
"Show full event" => "Näita kogu sündmust",
"Show only busy" => "Näita ainult hõivatud",
"Hide event" => "Peida sündmus",
"Does not repeat" => "Ei kordu",
"Daily" => "Iga päev",
"Weekly" => "Iga nädal",
"Every Weekday" => "Igal nädalapäeval",
"Bi-Weekly" => "Üle nädala",
"Monthly" => "Igal kuul",
"Yearly" => "Igal aastal",
"never" => "mitte kunagi",
"by occurrences" => "toimumiskordade järgi",
"by date" => "kuupäeva järgi",
"by monthday" => "kuu päeva järgi",
"by weekday" => "nädalapäeva järgi",
"events week of month" => "ürituse kuu nädal",
"first" => "esimene",
"second" => "teine",
"third" => "kolmas",
"fourth" => "neljas",
"fifth" => "viies",
"last" => "viimane",
"by events date" => "ürituste kuupäeva järgi",
"by yearday(s)" => "aasta päeva(de) järgi",
"by weeknumber(s)" => "nädala numbri(te) järgi",
"by day and month" => "kuu ja päeva järgi",
"Contact birthdays" => "Kontakti sünnipäevad",
"Date" => "Kuupäev",
"Cal." => "Kal.",
"Day" => "Päev",
"Week" => "Nädal",
"Month" => "Kuu",
"Today" => "Täna",
"CalDav Link" => "CalDav Link",
"Timezone" => "Ajavöönd",
"Update timezone automatically" => "Uuenda ajavööndit automaatselt",
"Time format" => "Ajavorming",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Nädal algab päevaga",
"Cache" => "Puhver",
"Clear cache for repeating events" => "Tühjenda korduvate ürituste puhver",
"Primary CalDAV address" => "Primaarne CalDAV aadress",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV aadress",
"Share Calendar" => "Jaga kalendrit",
"Download" => "Lae alla",
"Edit" => "Muuda",
"Delete" => "Kustuta",
"New calendar" => "Uus kalender",
"Edit calendar" => "Muuda kalendrit",
"Edit event" => "Muuda sündmust",
"Save event" => "Salvesta sündmus",
"Delete event" => "Kustuta sündmus",
"Eventinfo" => "Ürituse info",
"Repeating" => "Kordamine",
"Alarm" => "Alarm",
"Attendees" => "Osalejad",
"Share" => "Jaga",
"Title of the Event" => "Sündmuse pealkiri",
"from" => "alates",
"to" => "kuni",
"All Day Event" => "Kogu päeva sündmus",
"Advanced options" => "Lisavalikud",
"Location" => "Asukoht",
"Categories (separate by comma)" => "Kategooriad (eralda komaga)",
"Edit categories" => "Muuda kategooriaid",
"Description" => "Kirjeldus",
"Export event" => "Ekspordi sündmus",
"Repeat" => "Korda",
"Advanced" => "Täpsem",
"Select weekdays" => "Vali nädalapäevad",
"Select days" => "Vali päevad",
"and the events day of year." => "ja ürituse päev aastas.",
"and the events day of month." => "ja ürituse päev kuus.",
"Select months" => "Vali kuud",
"Select weeks" => "Vali nädalad",
"and the events week of year." => "ja ürituse nädal aastas.",
"Interval" => "Intervall",
"End" => "Lõpp",
"occurrences" => "toimumiskordi",
"Visibility to people shared with" => "Nähtavus jagamisel",
"create a new calendar" => "loo uus kalender",
"Import a calendar file" => "Impordi kalendrifail",
"Please choose a calendar" => "Palun vali kalender",
"Name of new calendar" => "Uue kalendri nimi",
"Take an available name!" => "Võta saadaolev nimi!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Selle nimega kalender on juba olemas. Kui sa siiski jätkad, siis need kalendrid liidetakse.",
"Remove all events from the selected calendar" => "Eemalda valitud kalendrist kõik sündmused",
"Import" => "Impordi",
"Close Dialog" => "Sulge dialoogiaken",
"Create a new event" => "Loo sündmus",
"Create event" => "Loo sündmus",
"Share with user or group" => "Jaga kasutaja või grupiga",
"Unshare" => "Lõpeta jagamine",
"Not shared with anyone" => "Pole kellegagi jagatud",
"Send Email" => "Saada e-post",
"Shared via calendar" => "Jaga läbi kalendri",
"Not shared with anyone via calendar" => "Pole kellegagi jagatud kalendri kaudu",
"View an event" => "Vaata üritust",
"Category" => "Kategooria",
"No categories selected" => "Ühtegi kategooriat pole valitud",
"%s of %s" => "%s  %s",
"Access Class" => "Ligipääsu klass",
"From" => "Alates",
"at" => "kell",
"To" => "Kuni"
);
